Admins class

Constructors

Admins(Client client)
const

Properties

client → Client
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(AdminId id) → Future<Admin>
list() → Future<List<Admin>>
me() → Future<Admin>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAwayMode(AdminId id, {required bool enabled, required bool reassign}) → Future<Admin>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited