PaginatedPagesCursorNext class

Inheritance

Constructors

PaginatedPagesCursorNext({required int page, required String? startingAfter})
const
PaginatedPagesCursorNext.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
page → int
final
query → Map<String, String>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startingAfter → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited